### 0.2

**Feature**

*MSFT-1238 Token Authentication*

- Update authentication docs [Artur Barseghyan]
- Implement token authentication [Artur Barseghyan]

*MSFT-1237 Improve Document Sharing*

- Improve document sharing. Add option to share via GDrive [Artur Barseghyan]
